@@ -20,6 +20,16 @@ namespace binder {
 using namespace ost;
 using namespace std;
 
+class Image : public ScriptImage
+{
+private:
+    Image() : ScriptImage(NULL, NULL) {};
+
+public:
+    inline void *alloc(size_t size)
+		{return ScriptImage::alloc(size);};
+};
+
 const char *Checks::chkJoin(Line *line, ScriptImage *img)
 {
 	if(line->argc)
@@ -241,8 +251,9 @@ const char *Checks::chkRegister(Line *line, ScriptImage *img)
 	return driver->registerScript(img, line);
 }
 
-const char *Checks::chkKeydata(Line *line, ScriptImage *img)
+const char *Checks::chkKeydata(Line *line, ScriptImage *ip)
 {
+	Image *img = (Image *)ip;
 	Name *scr = img->getCurrent();
 	BayonneDriver *driver;
 	const char *cp;
@@ -269,7 +280,18 @@ const char *Checks::chkKeydata(Line *line, ScriptImage *img)
 		slog.warn("cannot register keydata %s with driver", scr->name);
 		return "";
 	}
-	cp = driver->registerScript(img, line);
+
+	cp = findKeyword(img, line, "type");
+	if(cp && !strnicmp(cp, "ext", 3))
+		return "extensions not supported for xml app server binding";
+
+	if(cp && !stricmp(cp, "agent"))		
+		return "acd agents not support for xml app server binding";
+
+	line->scr.method = (Method)&Methods::scrKeydata;
+	line = (Line *)memcpy(img->alloc(sizeof(Line)), line, sizeof(Line));
+
+	cp = driver->registerScript(ip, line);
 	if(cp && *cp)
 		return cp;
 	return NULL;
