@@ -290,11 +290,13 @@ bool Methods::scrStart(void)
 	const char *display = getKeyword("display");
 	Symbol *sym = getKeysymbol("session", 16);
 	BayonneSession *child;
-	const char *cp, *id;
+	const char *cp, *id, *value;
 	char buf[65];
 	bool dg = false;
 	const char *encoding = getKeyword("encoding");
 	timeout_t framing = getTimeoutKeyword("framing");
+	unsigned pos;
+	Line *line = getLine();
 
 	if(framing == TIMEOUT_INF)
 		framing = 0;
@@ -351,6 +353,29 @@ bool Methods::scrStart(void)
 		child->setConst(id, sym->data);
 	}
 
+	while(line->next && !stricmp(line->next->cmd, "param"))
+	{
+		skip();
+		line = getLine();
+		pos = 0;
+		while(pos < line->argc)
+		{
+			id = line->args[pos++];
+			if(!id)
+				break;
+
+			if(*id != '=')
+				continue;
+
+			++id;
+			value = getContent(line->args[pos++]);
+			if(!value || !*id)
+				continue;
+			snprintf(buf, sizeof(buf), "param.%s", id);
+			child->setConst(buf, value);
+		}
+	}
+
 	child->leave();
 	advance();
 	return true;
@@ -365,13 +390,14 @@ bool Methods::scrConnect(void)
 	const char *display = getKeyword("display");
 	Symbol *sym = getKeysymbol("session", 16);
 	BayonneSession *child;
-	const char *cp, *id;
+	const char *cp, *id, *value;
 	char buf[65];
 	TelTone::tonekey_t *key = NULL;
 	Audio::Level level = 26000;
 	bool dg = false;
 	const char *encoding = getKeyword("encoding");
 	timeout_t framing = getTimeoutKeyword("framing");
+	unsigned pos = 0;
 
 	if(framing == TIMEOUT_INF)
 		framing = 0;
@@ -476,6 +502,26 @@ bool Methods::scrConnect(void)
 		child->setConst(id, sym->data);
 	}
 
+	while(line->next && !stricmp(line->next->cmd, "param"))
+	{
+		skip();
+		line = getLine();
+		pos = 0;
+		while(pos < line->argc)
+		{
+			id = line->args[pos++];
+			if(*id != '=')
+				continue;
+			++id;
+			value = getContent(line->args[pos++]);
+			if(*id && value)
+			{
+				snprintf(buf, sizeof(buf), "param.%s", id);
+				child->setConst(buf, value);
+			}
+		}
+	}	
+
 	child->startConnecting();
 	child->leave();
 	setState(STATE_CONNECT);
