@@ -1052,7 +1052,9 @@ void Bayonne::errlog(const char *level, const char *fmt, ...)
 		Bayonne::server->errlog(level, buffer);
 }
 	
-BayonneSession *Bayonne::startDialing(const char *dial, const char *name, const char *caller, const char *display, BayonneSession *parent, const char *manager)
+BayonneSession *Bayonne::startDialing(const char *dial, 
+	const char *name, const char *caller, const char *display, 
+	BayonneSession *parent, const char *manager, const char *proxy)
 {
 	ScriptImage *img;
 	BayonneDriver *d = BayonneDriver::getTrunking();
@@ -1280,6 +1282,8 @@ start:
 	}
 	session->setConst("session.caller", caller);
 	session->setConst("session.display", display);
+	if(proxy)
+		session->setConst("session.proxyauth", proxy);
 
         if(!session->postEvent(&event))
         {
