@@ -85,6 +85,7 @@ class __EXPORT BayonneSpan;
 class __EXPORT BayonneService;
 class __EXPORT BayonneTranslator;
 class __EXPORT BayonneRPC;
+class __EXPORT ScriptEngine;
 
 /**
  * Streaming buffer for audio, to be used in bgm audio sources.
@@ -481,6 +482,8 @@ public:
 		ENTER_RECONNECT,
 		EXIT_RECONNECT,
 		RECALL_RECONNECT,
+		EXIT_SCRIPT,
+		STEP_SCRIPT,
 
 		// primary session control events
 
@@ -1149,7 +1152,8 @@ public:
 	 */
 	static BayonneSession *startDialing(const char *dial, 
 		const char *name, const char *caller, const char *display, 
-		BayonneSession *parent = NULL, const char *manager = NULL);
+		BayonneSession *parent = NULL, const char *manager = NULL,
+		const char *secret = NULL);
 
 	/**
 	 * Returns a session pointer for a string identifier.  This can
@@ -1590,6 +1594,7 @@ public:
 		{return id;};
 };
 
+
 /**
  * Offers core Bayonne audio processing in a self contained class.  The
  * BayonneAudio class is used with each session object.
@@ -1819,6 +1824,9 @@ public:
 	 */
 	virtual bool isAuthorized(const char *userid, const char *secret);
 
+	virtual bool deregister(const char *id);
+	virtual bool reregister(const char *id, const char *uri, const char *secret, timeout_t expires);
+
 	Traffic call_attempts, call_complete;
 	volatile unsigned short active_calls;
 
@@ -2446,6 +2454,7 @@ public:
 class __EXPORT BayonneSession : public ScriptInterp, public Bayonne
 {
 private:
+	friend class __EXPORT ScriptEngine;
 	friend class __EXPORT BayonneMsgport;
 	friend class __EXPORT BayonneTranslator;
 	friend class __EXPORT BayonneDriver;
@@ -2477,6 +2486,7 @@ protected:
 	bridge_t bridge;
 	calltype_t type;
 	event_t seizure;
+	ScriptEngine *vm;
 
 //	Name *getScript(const char *scr);
 
@@ -2660,6 +2670,9 @@ public:
 	inline timeslot_t getTimeslot(void)
 		{return timeslot;};
 
+	inline ScriptEngine *getEngine(void)
+		{return vm;};
+
 	/**
 	 * Process interpreter session symbols.
 	 *
@@ -2876,6 +2889,9 @@ public:
 	inline const char *getSessionParent(void)
 		{return var_pid;};
 
+	inline const char *getSessionJoined(void)
+		{return var_joined;};
+
 	inline time_t getSessionStart(void)
 		{return starttime;};
 
@@ -3118,8 +3134,7 @@ public:
 	 * @param signal to send to script engine.
 	 * @return true if signal claimed.
 	 */
-	inline bool signalScript(signal_t signal)
-		{return ScriptInterp::signal(signal);};
+	bool signalScript(signal_t signal);
 
 	/**
 	 * Indicate whether session peers audio as linear frames.
@@ -3256,6 +3271,7 @@ public:
 	const char *getNamed(unsigned short param, const char *member);
 	const char *getMapped(const char *map, const char *member);
 
+	friend size_t xmlwrite(char **buf, size_t *max, const char *fmt, ...);
 	bool buildResponse(const char *fmt, ...);
 	void sendSuccess(void);
 	void sendFault(int code, const char *string);
@@ -3265,6 +3281,8 @@ public:
 
 	bool invokeXMLRPC(void);
 };	
+
+size_t xmlwrite(char **buf, size_t *max, const char *fmt, ...);
 	 
 /**
  * Bayonne services are used for threaded modules which may be
@@ -3319,10 +3337,79 @@ protected:
 	virtual void exitingCall(BayonneSession *child);
 
 public:
+	/**
+	 * Start all service threads.
+	 */
 	static void start(void);
+	
+	/**
+	 * Stop all service threads.
+	 */
 	static void stop(void); 
 };
 
+/**
+ * Offers interface bridge for embedded scripting engines through an
+ * abstract interface.  This may be used to support calling of integrated
+ * virtual machines, etc.
+ *
+ * @author David Sugar <dyfet@gnutelephony.org>
+ * @short vm scripting interface bridge.
+ */
+class __EXPORT ScriptEngine
+{
+protected:
+	friend class __EXPORT BayonneSession;
+
+	/**
+	 * Signal bridge about Bayonne signal event.
+	 *
+	 * @param bayonne signal event
+	 * @return true if claimed by scripting engine
+	 */
+	virtual bool signalEngine(Bayonne::signal_t signal) = 0;
+
+	/**
+	 * Release bridge session because we moved.  If detached thread
+	 * then should also NULL the vm pointer.
+	 */
+	virtual void releaseEngine(void) = 0;
+
+	/**
+	 * Disconnect bridge session for hangup/stopping of processing.  If
+	 * detached thread, then should also NULL the vm pointer.
+	 */
+	virtual void disconnectEngine(void) = 0;
+
+	/**
+	 * Step notification, often used to signal completion handler so
+	 * bridge can change state of Bayonne engine and then wait for
+	 * completion by notification at running state again.  Hence
+	 * we often use a Common C++ "Event" object for completion notify.
+	 *
+	 * @param true if to continue step counter also.
+	 */
+	virtual bool stepEngine(void) = 0;
+
+	/**
+	 * If not detached thread we may delete it ourselves.
+	 */
+	virtual ~ScriptEngine() = 0;
+
+	/*
+	 * Clears vm session.
+	 */
+	inline void clearEngine(BayonneSession *s)
+		{s->vm = NULL;};
+
+	/**
+	 * Set vm session.
+	 */
+	inline void setEngine(BayonneSession *s)
+		{s->vm = this;};
+};
+
+
 } // namespace
 
 #endif
