@@ -21,6 +21,27 @@ using namespace std;
 
 BayonneBinder *BayonneBinder::binder = NULL;
 
+unsigned BayonneBinder::Image::gatherPrefix(const char *prefix, const char **list, unsigned max)
+{
+	unsigned count = 0;
+	unsigned key = 0;
+	Name *scr;
+	unsigned len = strlen(prefix);
+
+	while(count < max && key < SCRIPT_INDEX_SIZE)
+	{
+		scr = index[key];
+		while(scr && count < max)
+		{
+			if(!strnicmp(scr->name, prefix, len))
+				list[count++] = scr->name + len;
+			scr = scr->next;
+		}
+		++key;
+	}
+	return count;
+}
+
 BayonneBinder::BayonneBinder(const char *id) :
 ScriptBinder(id)
 {
@@ -28,6 +49,24 @@ ScriptBinder(id)
 		binder = this;
 }
 
+bool BayonneBinder::isDestination(const char *dest)
+{
+	bool rtn = false;
+	Image *img = (Image *)useImage();
+	if(binder && img)
+		rtn = binder->isDestination(img, dest);
+	if(img)
+		endImage(img);
+	return rtn;
+}
+
+unsigned BayonneBinder::gatherDestinations(ScriptImage *img, const char **list, unsigned max)
+{
+	if(binder)
+		return binder->destinations((Image *)img, list, max);
+	return 0;
+}
+
 Script::Name *BayonneBinder::getIncoming(ScriptImage *img, BayonneSession *s, Event *event)
 {
 	BayonneSpan *span = s->getSpan();
@@ -103,4 +142,18 @@ void BayonneBinder::dropCall(BayonneSession *s)
 {
 }
 
+unsigned BayonneBinder::destinations(Image *img, const char **list, unsigned max)
+{
+	return img->gatherPrefix("dialed::", list, max);
+}
+
+bool BayonneBinder::isDestination(Image *img, const char *check)
+{
+	char buf[80];
+	snprintf(buf, sizeof(buf), "dialed::%s", check);
+	if(img->getScript(buf))
+		return true;
+
+	return false;
+}
 
