@@ -81,6 +81,16 @@ BayonneDriver::~BayonneDriver()
 	}
 }
 
+bool BayonneDriver::deregister(const char *id)
+{
+	return false;
+}
+
+bool BayonneDriver::reregister(const char *id, const char *uri, const char *secret, timeout_t duration)
+{
+	return false;
+}
+
 bool BayonneDriver::suspend(void)
 {
 	return false;
@@ -428,6 +438,7 @@ BayonneDriver *BayonneDriver::authorize(const char *userid, const char *secret)
 BayonneDriver *BayonneDriver::get(const char *id)
 {
 	BayonneDriver *driver = firstDriver;
+	const char *cp;
 
 	if(!id)
 		return driver;
@@ -436,6 +447,17 @@ BayonneDriver *BayonneDriver::get(const char *id)
 	{
 		if(!stricmp(driver->name, id))
 			break;
+		cp = driver->getLast("type");
+		if(cp && !strnicmp(cp, "proto", 5))
+		{
+			cp = driver->getLast("proto");
+			if(!cp)
+				cp = driver->getLast("protocol");
+		}
+		else
+			cp = NULL;
+		if(cp && !stricmp(cp, id))
+			break;
 		driver = driver->nextDriver;
 	}
 	return driver;
