@@ -36,7 +36,7 @@ static const char *get_config(const char *path)
 #ifdef	WIN32
 		env = NULL;
 #else
-		env = Process::getEnv("BAYONNE_CONFIG");
+		env = Process::getEnv("CONFIG");
 		if(!getuid())
 		{
 			if(!Process::getEnv("HOME"))
