@@ -171,11 +171,14 @@ static char *parseText(char *cp)
 	return rp;
 }
 
-static char *parseValue(char *cp, char **value)
+static char *parseValue(char *cp, char **value, char **map)
 {
 	*value = NULL;
 	bool base64 = false;
 
+	if(map)
+		*map = NULL;	
+
 	while(*cp)
 	{
 		while(isspace(*cp))
@@ -190,13 +193,17 @@ static char *parseValue(char *cp, char **value)
 
 		if(!strncmp(cp, "<struct>", 8))
 			return cp + 8;
+		else if(!strncmp(cp, "<array>", 7))
+			return cp + 7;
 
-		if(*cp == '<')
+		if(*cp == '<' && cp[1] != '/')
 		{
+			if(map)
+				*map = ++cp;
 			while(*cp && *cp != '>')
 				++cp;
 			if(*cp == '>')
-				++cp;
+				*(cp++) = 0;
 			continue;
 		}
 
@@ -238,7 +245,6 @@ static char *parseName(char *cp, char **value)
 	return cp;
 }
 
-
 BayonneRPC::BayonneRPC()
 {
 }
@@ -279,7 +285,7 @@ bool BayonneRPC::parseCall(char *cp)
 			cp += 12;
 			continue;
 		}
-		if(!strncmp(cp, "<?", 2))
+		if(!strncmp(cp, "<?", 2) || !strncmp(cp, "<!", 2))
 		{
 			while(*cp && *cp != '>')
 				++cp;
@@ -327,7 +333,7 @@ bool BayonneRPC::parseCall(char *cp)
 		if(!strncmp(cp, "<value>", 7))
 		{
 			params.param[params.count] = params.argc;
-			cp = parseValue(cp, &value);
+			cp = parseValue(cp, &value, NULL);
 			if(value)
 				params.value[params.count++] = value;
 			else if(name_flag)
@@ -457,11 +463,89 @@ void BayonneRPC::sendFault(int code, const char *string)
 		"</methodResponse>\r\n");
 }
 
+size_t xmlwrite(char **bufp, size_t *max, const char *fmt, ...)
+{
+	const char *sv;
+	int iv;
+	long lv;
+	time_t tv;
+	va_list args;
+	unsigned count;
+	size_t used = *max;
+	char *buf = *bufp;
+	struct tm *dt, dbuf;
+
+	va_start(args, fmt);
+
+	while(*fmt && *max > 1)
+	{
+		if(*fmt == '%')
+		{
+			count = 0;
+			switch(*(++fmt))
+			{
+			case 't':
+				tv = va_arg(args, time_t);
+				dt = localtime_r(&tv, &dbuf);
+                if(dt->tm_year < 1800)
+                    dt->tm_year += 1900;
+                count = xmlformat(buf, *max, "%04d%02d%02dT%02d:%02d:%02d",
+                    dt->tm_year, dt->tm_mon + 1, dt->tm_mday,
+                    dt->tm_hour, dt->tm_min, dt->tm_sec);
+				break;
+			case 'd':
+				iv = va_arg(args, int);
+				count = xmlformat(buf, *max, "%d", iv);
+				break;
+            case 'l':
+                lv = va_arg(args, int);
+                count = xmlformat(buf, *max, "%ld", lv);
+                break;
+			case 'q':
+				sv = va_arg(args, const char *);
+				if(*max > 1)
+				{
+					*(buf++) = '\"';
+					--*max;
+				}
+				count = xmltext(buf, *max, sv);
+				*max -= count;
+				buf += count;
+				if(*max > 1)
+				{
+					(*buf++) = '\"';
+					--*max;
+				}
+				count = 0;
+				break;	
+			case 's':
+				sv = va_arg(args, const char *);
+				count = xmltext(buf, *max, sv);
+			default:
+				break;
+			}
+			++fmt;	
+			buf += count;
+			*max -= count;
+		}
+		else
+		{
+			*(buf++) = *(fmt++);
+			--*max;
+		}
+	}
+
+	*buf = 0;
+	*bufp = buf;
+	va_end(args);
+	return used - *max;
+}
+
 bool BayonneRPC::buildResponse(const char *fmt, ...)
 {
 	rpcint_t iv;
 	time_t tv;
-	struct tm *dt;
+	struct tm *dt, dbuf;
 	double dv;
 	const unsigned char *xp;
 	size_t xsize;
@@ -621,7 +705,7 @@ bool BayonneRPC::buildResponse(const char *fmt, ...)
 				break;
 			case 't':
 				tv = va_arg(args, time_t);
-				dt = localtime(&tv);
+				dt = localtime_r(&tv, &dbuf);
 				if(dt->tm_year < 1800)
 					dt->tm_year += 1900;
 				count += xmlformat(buffer + count, max - count,
