@@ -43,6 +43,7 @@ using namespace std;
 
 static Keydata::Define driver[] = {
 	{"type", "proto"},
+	{"proto", "h323"},
 	{"stack", "0"},
 	{"events", "128"},
 	{"priority", "0"},
@@ -101,7 +102,7 @@ void Driver::startDriver(void)
         PIPSocket::Address interfaceAddress(getLast("interface"));
         WORD port = atoi(getLast("port"));
 	unsigned retries = 0;
-	const char *cp = getLast("slots.h323");
+	const char *cp = getLast("timeslots");
 
 	if(cp)
 		max_count = atoi(cp);
