@@ -297,6 +297,115 @@ void Driver::reloadDriver(void)
 	}
 }
 
+bool Driver::reregister(const char *id, const char *uri, const char *secret, timeout_t expires)
+{
+    ScriptImage *img;
+    Registry *reg;
+    char buf[32];
+    bool rtn = false;
+    osip_message_t *msg = NULL;
+	const char *cp;
+
+    if(!strnicmp(id, "sip:", 4))
+        id += 4;
+
+	if(!deregister(id) || !secret)
+		return false;
+		
+    snprintf(buf, sizeof(buf), "uri.%s", id);
+    img = useImage();
+    if(!img)
+		return false;
+
+    reg = (Registry *)img->getPointer(buf);
+	if(!reg)
+		goto final;
+
+	if(!strnicmp(uri, "sip:", 4))
+		setString(reg->traffic->address, sizeof(reg->traffic->address), uri);
+	else
+		snprintf(reg->traffic->address, sizeof(reg->traffic->address), 
+			"sip:%s", uri);
+
+	reg->proxy = strchr(reg->traffic->address, '@');
+	if(reg->proxy)
+		++reg->proxy;
+	else
+		goto final;
+
+	reg->uri = reg->traffic->address;
+	setString(reg->traffic->secret, sizeof(reg->traffic->secret), secret);
+	reg->secret = reg->traffic->secret;
+	reg->duration = expires;
+
+    eXosip_lock();
+    reg->regid = eXosip_register_build_initial_register((char *)reg->uri, (char *)reg->proxy, (char *)reg->contact, reg->duration / 1000, &msg);
+    eXosip_unlock();
+
+	if(reg->regid < 0)
+		goto final;
+
+    osip_message_set_header(msg, "Event", "Registration");
+    osip_message_set_header(msg, "Allow-Events", "presence");
+    cp = getLast("transport");
+    if(cp && !stricmp(cp, "tcp"))
+        eXosip_transport_set(msg, "TCP");
+    else if(cp && !stricmp(cp, "tls"))
+        eXosip_transport_set(msg, "TLS");
+    eXosip_lock();
+    eXosip_register_send_register(reg->regid, msg);
+    eXosip_unlock();
+	rtn = true;
+	snprintf(buf, sizeof(buf), "sipreg.%d", reg->regid);
+	img->setPointer(buf, reg);
+
+final:
+	if(reg && !rtn)
+	{
+		reg->proxy = NULL;
+		reg->duration = 0;
+		reg->regid = -1;
+	}
+
+	endImage(img);
+	return rtn;
+}
+
+bool Driver::deregister(const char *id)
+{
+	ScriptImage *img;
+	Registry *reg;
+	char buf[32];
+	bool rtn = false;
+
+	if(!strnicmp(id, "sip:", 4))
+		id += 4;
+
+	snprintf(buf, sizeof(buf), "uri.%s", id);
+	img = useImage();
+	if(!img)
+		return false;
+
+	reg = (Registry *)img->getPointer(buf);
+	if(!reg || strnicmp(reg->type, "dyn", 3))
+		goto final;
+
+	rtn = true;
+	if(reg->regid < 0)
+		goto final;
+
+	updateExpires(reg, 0);
+	snprintf(buf, sizeof(buf), "sipreg.%d", reg->regid);
+	img->setPointer(buf, NULL);
+	reg->regid = -1;
+	reg->proxy = NULL;	
+	reg->duration = 0;
+
+final:
+	endImage(img);
+	return rtn;
+}
+
 bool Driver::isReachable(const char *proxy)
 {
 	char buf[128];
@@ -441,6 +550,8 @@ bool Driver::isRegistered(const char *ext)
 		rtn = reg->isActive();
 	else if(reg && !stricmp(reg->type, "gw"))
 		rtn = reg->isActive();
+	else if(reg && !strnicmp(reg->type, "dyn", 3))
+		rtn = reg->isActive();
 	endImage(img);
 	return rtn;
 }
@@ -572,6 +683,8 @@ unsigned Driver::getRegistration(regauth_t *data, unsigned count, const char *id
 		uid = reg->localid;
 		if(!uid)
 			uid = reg->userid;
+		if(!uid && !strnicmp(reg->type, "dyn", 3))
+			uid = "unknown";
 
 		if(id && !uid)
 			goto skip;
@@ -589,7 +702,17 @@ unsigned Driver::getRegistration(regauth_t *data, unsigned count, const char *id
 			data[idx].remote = reg->proxy;
 		data[idx].userid = uid;
 		data[idx].type = reg->type;
-		if(anon)
+		if(!strnicmp(reg->type, "dyn", 3))
+		{
+			if(reg->proxy)
+				data[idx].status = "active";
+			else
+			{
+				data[idx].status = "unused";
+				data[idx].remote = "none";
+			}
+		}
+		else if(anon)
 			data[idx].status = "active";
 		else if((ext || gw) && !reg->traffic->active)
 			data[idx].status = "offline";
@@ -655,18 +778,41 @@ bool Driver::getAuthentication(Session *s, osip_message_t *resp)
 	ScriptImage *img = s->getImage();
 	const char *cp = s->getSymbol("session.registry");
 	char *p;
+	const char *proxy = s->getSymbol("session.proxyauth");
 	Registry *reg;
 	bool rtn = false;
-	const char *realm;
+	const char *realm = NULL;
         osip_proxy_authenticate_t *prx_auth = NULL;
         osip_www_authenticate_t *www_auth = NULL;
 
+
         if(resp)
         {
 		prx_auth = (osip_proxy_authenticate_t*)osip_list_get(OSIP2_LIST_PTR resp->proxy_authenticates, 0);
                 www_auth = (osip_proxy_authenticate_t*)osip_list_get(OSIP2_LIST_PTR resp->www_authenticates,0);
         }
 
+	if(proxy && strchr(proxy, ':') && (prx_auth != NULL|www_auth != NULL))
+	{
+        if(prx_auth)
+                realm = osip_proxy_authenticate_get_realm(prx_auth);
+        else if(www_auth)
+                realm = osip_www_authenticate_get_realm(www_auth);
+
+		setString(buf, sizeof(buf), s->getSymbol("session.caller"));
+		p = strchr(buf, ':');
+		if(p)		
+			*(p++) = 0;
+
+		eXosip_lock();
+		if(eXosip_add_authentication_info(buf, buf, p, NULL, realm))
+			slog.error("sip: proxy authentication failed");
+		else
+			rtn = true;
+		eXosip_unlock();
+		goto done;
+	}
+
 	if(!cp)
 		goto done;
 
@@ -1820,6 +1966,13 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 	if(!registry)
 		registry = true;
 
+	if(!strnicmp(reg->type, "dyn", 3))
+	{
+		reg->regid = -1;
+		reg->proxy = NULL;
+		goto add;
+	}
+
 	eXosip_lock();
 	reg->regid = eXosip_register_build_initial_register((char *)reg->uri, (char *)reg->proxy, (char *)reg->contact, reg->duration / 1000, &msg);
 	eXosip_unlock();
@@ -1880,8 +2033,16 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 add:
 	snprintf(buf, sizeof(buf), "uri.%s", reg->localid);
 	reg->traffic = Driver::sip.getTraffic(buf);
+	if(reg->traffic->secret[0])
+		reg->secret = reg->traffic->secret;
+
 	if(reg->traffic->address[0])
+	{
 		reg->proxy = reg->traffic->address;
+		cp = strchr(reg->proxy, '@');
+		if(cp)
+			reg->proxy = ++cp;
+	} 
 	img->setPointer(buf, reg);
 	img->addRegistration(line);
 	line->scr.registry = reg;
