@@ -751,6 +751,8 @@ bool Session::enterSeize(Event *event)
 	unsigned idx;
 	bool offline = false;
 	unsigned short instance = 0;
+	const char *proxy;
+	char *ep;
 
 	switch(event->id)
 	{
@@ -858,9 +860,9 @@ dialer:
 					reg->userid, reg->proxy);
 				if(!route)
 					route = reg->proxy;
-				sp = strrchr(buf, ':');
-				if(sp && !stricmp(sp, ":5060"))
-					*sp = 0;
+				ep = strrchr(buf, ':');
+				if(ep && !stricmp(sp, ":5060"))
+					*ep = 0;
 				setConst("session.uri_remote", buf);
 				goto dialing;
 			}
@@ -891,6 +893,7 @@ dialer:
 		}
 dialing:
 		dtmf_sipinfo = Driver::sip.info_negotiate;
+		proxy = getSymbol("proxyauth");
 		if(reg)
 		{
 			if(reg->dtmf && !stricmp(reg->dtmf, "info"))
@@ -918,8 +921,24 @@ dialing:
 			setConst("session.registry", rbuf);
 			setConst("session.uri_server", reg->proxy);
 			setConst("session.uri_local", reg->contact);
-			setConst("session.uri_caller", reg->uri);
-			caller = reg->caller;
+			if(proxy && *proxy)
+			{
+				snprintf(buf, sizeof(buf), "sip:%s", proxy);
+				ep = strchr(buf, ':');
+				if(ep)
+					*ep = 0;
+				cp = strchr(reg->uri, '@');
+				if(cp)
+					addString(buf, sizeof(buf), cp);
+				setConst("session.uri_caller", buf);
+				caller = NULL;
+			}
+			else
+			{
+				caller = reg->caller;
+            	setConst("session.uri_caller", reg->uri);
+			}
+
                         if(reg->address)
                         {
                                 InetAddress host(reg->address);
@@ -945,8 +964,20 @@ dialing:
 		}
 		else
 		{
+			if(proxy && *proxy)
+			{
+				setString(buf, sizeof(buf), "sip:");
+				addString(buf, sizeof(buf), proxy);
+				ep = strchr(buf, ':');
+				if(ep)
+					*ep = 0;
+				addString(buf, sizeof(buf), "@");
+				addString(buf, sizeof(buf), 
+					Driver::sip.getLast("interface"));
+				setConst("session.uri_caller", buf);
+			}
 			snprintf(buf, sizeof(buf), "sip:anon@%s",
-				Driver::sip.getLast("interface"));
+					Driver::sip.getLast("interface"));
 			setConst("session.uri_local", buf);
 			setConst("session.uri_caller", buf);
                         setConst("session.ip_local", lp);
