@@ -40,8 +40,8 @@ Session::~Session()
 	if(so != INVALID_SOCKET)
 	{
 		SLOG_DEBUG("webservice/%d: ending session", so);
+		endSocket();
 	}
-	endSocket();
 	terminate();
 
 	if(transport.buffer)
@@ -140,8 +140,11 @@ char *Session::urlDecode(char *source)
 
 void Session::syncExit(void)
 {
-	SLOG_DEBUG("webservice/%d: ending session", so);
-	endSocket();
+	if(so != INVALID_SOCKET)
+	{
+		SLOG_DEBUG("webservice/%d: ending session", so);
+		endSocket();
+	}
 	Thread::exit();
 }
 
@@ -212,7 +215,7 @@ void Session::sendText(const char *text)
 	if(::send(so, text, len, flag) < (int)len)
 	{
 		if((errno == EPIPE) || (errno == ECONNRESET))
-			Thread::exit();
+			syncExit();
 	}
 }
 
@@ -255,8 +258,9 @@ void Session::run(void)
 	const char *ext;
 	char agent[65];
 	char secret_buf[65];
-	unsigned xmlsize = 0;
+	unsigned long xmlsize = 0;
 	bool xmltext = false;
+	BayonneDriver *d;
 
 	if(readLine(request, sizeof(request), 10000) < 1)
 	{
@@ -302,7 +306,7 @@ timeout:
 			while(isspace(*cp))
 				++cp;
 
-			xmlsize = atoi(cp);
+			xmlsize = atol(cp);
 		} 
 
 		if(!strnicmp(buffer, "User-Agent:", 11))
@@ -359,24 +363,133 @@ timeout:
 		}
 	}
 
+	if(strstr(req_path, ".."))
+		rpcFault(403, "Path Invalid");
+
 	ext = strrchr(req_path, '.');
 	if(!ext)
 		ext = "";
-	if(!stricmp(ext, ".xml"))
+	if(!stricmp(ext, ".html") && Service::webservice.getBoolean("authenticate"))
 	{
 		if(!req_auth || !userid || !passwd)
-			xmlFault(401, "Authorization Required");
-		secret = Service::webservice.rpc.getString(userid, secret_buf, sizeof(secret_buf));
-		if(!secret || strcmp(secret, passwd))
-			xmlFault(401, "Authorization Invalid");
-	}
-	else if(!stricmp(ext, ".html"))
-	{
-		if(!req_auth || !userid || !passwd)
-			xmlFault(401, "Authorization Required");
+			rpcFault(401, "Authorization Required");
 		secret = Service::webservice.admin.getString(userid, secret_buf, sizeof(secret_buf));
 		if(!secret || strcmp(secret, passwd))
-			xmlFault(401, "Authorization Invalid");
+			rpcFault(401, "Authorization Invalid");
+	}
+
+	if(strchr(req_path, '/'))
+	{
+		if(!req_auth || !userid || !passwd)
+			rpcFault(401, "Authorization Required");
+
+		secret = Service::webservice.admin.getString(userid, secret_buf, sizeof(secret_buf));
+		if(secret && !strcmp(secret, passwd))
+			goto allow;
+	
+		rpcFault(403, "Access Forbidden");
+	}
+
+allow:
+	if(!stricmp(req_command, "post") && *ext && strchr(req_path, '/'))
+	{
+		if(!xmlsize)
+			rpcFault(411, "No Size Specified");			
+		postDocument(req_path, xmlsize);
+	}
+	if(!stricmp(req_command, "get") && *ext)
+	{
+		if(!stricmp(ext, ".dtd"))
+			textDocument(req_path, "application/xml-dtd");
+		if(!stricmp(ext, ".css"))
+			textDocument(req_path, "text/css");
+		if(!stricmp(ext, ".txt") || !stricmp(ext, ".text"))
+			textDocument(req_path, "text/plain");
+		if(!stricmp(ext, ".au") || !stricmp(ext, ".snd"))
+			binDocument(req_path, "audio/basic");
+		if(!stricmp(ext, ".wav") || !stricmp(ext, ".wave"))
+			binDocument(req_path, "audio/x-wav");
+		if(!stricmp(ext, ".gsm"))
+			binDocument(req_path, "audio/x-gsm");
+		if(!stricmp(ext, ".jpg") || !stricmp(ext, ".jpeg"))
+			binDocument(req_path, "image/jpeg");
+		if(!stricmp(ext, ".ico") || !stricmp(ext, ".icon"))
+			binDocument(req_path, "image/x-icon");
+		if(!stricmp(ext, ".mpg") || !stricmp(ext, ".mpeg"))
+			binDocument(req_path, "video/mpeg");
+		if(!stricmp(ext, ".ogg"))
+			binDocument(req_path, "application/ogg");
+		if(!stricmp(ext, ".gif"))
+			binDocument(req_path, "image/gif");
+		if(!stricmp(ext, ".png"))
+			binDocument(req_path, "image/png");
+		if(!stricmp(ext, ".js"))
+			textDocument(req_path, "application/x-javascript");
+		if(!stricmp(ext, ".jar"))
+			binDocument(req_path, "application/java-archive");
+		if(!stricmp(ext, ".class"))
+			binDocument(req_path, "application/java-vm");
+		if(!stricmp(ext, ".pdf"))
+			binDocument(req_path, "application/pdf");
+		if(!stricmp(ext, ".ps"))
+			binDocument(req_path, "application/postscript");
+		if(!stricmp(ext, ".xhtml"))
+			textDocument(req_path, "application/xhtml+xml");
+	}
+
+	// client generated uuid based events access
+	if(!strnicmp(req_path, "events-uuid-", 12)) 
+	{
+		userid = (char *)req_path + 12;
+		goto events;
+	}
+
+	if(!stricmp(req_path, "events"))
+	{
+		if(!userid && Service::webservice.getBoolean("authenticate"))
+			rpcFault(401, "Authorization Required");
+
+		if(!userid)
+			goto events;
+
+		secret = Service::webservice.rpc.getString(userid, secret_buf, sizeof(secret_buf));
+		if(secret && passwd)
+			if(!strcmp(secret, passwd))
+			{
+				userid = NULL;
+				goto events;
+			}
+
+		if(strchr(userid, '/'))
+		{
+			driver = userid;
+			userid = strchr(userid, '/');
+            *(userid++) = 0;
+            d = BayonneDriver::get(driver);
+			if(d && !d->isAuthorized(userid, passwd))
+            	d = NULL;
+        }
+        else if(strchr(userid, ':'))
+        {
+            driver = userid;
+            userid = strchr(userid, ':');
+            *(userid++) = 0;
+            d = BayonneDriver::get(driver);
+            if(d && !d->isAuthorized(userid, passwd))
+                d = NULL;
+        }
+		else
+			d = BayonneDriver::authorize(userid, passwd);
+
+		if(!d)
+			rpcFault(401, "Authorization Invalid");
+
+events:
+		sendHeader("text/xml");
+		EventStream::create(so, userid);
+		so = INVALID_SOCKET;
+		state = Socket::INITIAL;
+		syncExit();
 	}
 
 	if(!stricmp(req_command, "post"))
@@ -400,7 +513,8 @@ timeout:
 				userid = strchr(userid, '/');
 				*(userid++) = 0;
 				transport.driver = BayonneDriver::get(driver);
-				if(transport.driver && !transport.driver->isAuthorized(userid, passwd))
+				if(transport.driver && 
+					!transport.driver->isAuthorized(userid, passwd))
 					transport.driver = NULL;
 			}
 			else if(strchr(userid, ':'))
@@ -458,51 +572,6 @@ timeout:
 		syncExit();
 	}			
 
-	if(!stricmp(req_path, "status.xml"))
-		xmlStatus();
-
-	if(!stricmp(req_path, "traffic.xml"))
-		xmlTraffic();
-
-	if(!stricmp(req_path, "timeslots.xml"))
-		xmlTimeslots();
-
-	if(!stricmp(req_path, "servicelevel.xml"))
-		xmlServicelevel();
-
-	if(!stricmp(req_path, "uptime.xml"))
-		xmlUptime();
-
-	if(!stricmp(req_path, "drivers.xml"))
-		xmlDrivers();
-
-	if(!stricmp(req_path, "registrations.xml"))
-		xmlRegistrations();
-
-	if(!stricmp(req_path, "calls.xml"))
-		xmlCalls();
-
-	if(!stricmp(req_path, "reload.xml"))
-		xmlReload();
-
-	if(!stricmp(req_path, "stop.xml"))
-		xmlStop();
-
-	if(!stricmp(req_path, "hold.xml"))
-		xmlHold();
-
-	if(!stricmp(req_path, "refer.xml"))
-		xmlRefer();
-
-	if(!stricmp(req_path, "resume.xml"))
-		xmlResume();
-
-	if(!stricmp(req_path, "start.xml"))
-		xmlStart();
-
-	if(!stricmp(req_path, "shutdown.xml"))
-		xmlShutdown();
-
 	if(!stricmp(req_path, "status.html"))
 		htmlStatus();
 
@@ -519,7 +588,119 @@ timeout:
 
 	cp = strrchr(req_path, '.');
 
-	xmlFault(404, "Not Found");	
+	rpcFault(404, "Not Found");	
+	syncExit();
+}
+
+void Session::postDocument(const char *file, unsigned long size)
+{
+    char buf[256];
+	char dbuf[512];
+    FILE *fp;
+	int len;
+	
+	snprintf(buf, sizeof(buf), "%s/%s",
+		Service::webservice.getString("datafiles"), file);
+
+	fp = fopen(buf, "w");
+	if(!fp)
+		rpcFault(403, "Not Writable");
+
+	while(size)
+	{
+		if(size > sizeof(dbuf))
+			len = sizeof(dbuf);
+		else
+			len = (int)size;
+
+		if(readData(dbuf, len) < len)
+		{
+fault:
+			remove(buf);
+			fclose(fp);
+			rpcFault(403, "Write Failed");
+		}
+		if(fwrite(dbuf, 1, len, fp) < 1)
+			goto fault;
+	}
+	fclose(fp);
+	rpcReply(NULL);
+}
+
+void Session::binDocument(const char *file, const char *ctype)
+{
+    char buf[256];
+    FILE *fp;
+	int len;
+	struct stat ino;
+
+	if(strchr(file, '/'))
+		snprintf(buf, sizeof(buf), "%s/%s",
+			server->getLast("prefix"), file);
+	else
+    	snprintf(buf, sizeof(buf), "%s/%s",
+        	Service::webservice.getString("datafiles"), file);
+
+	if(stat(buf, &ino))
+		rpcFault(404, "Not Found");
+	
+	fp = fopen(buf, "r");
+	if(!fp)
+		rpcFault(403, "Not Accessible");
+
+	sendHeader(ctype, ino.st_size);
+	for(;;)
+	{
+		len = fread(buf, 1, sizeof(buf), fp);	
+		if(len < 1)
+			break;
+
+		if(writeData(buf, len) < len)
+			syncExit();
+	}
+	fclose(fp);
+	syncExit();
+}
+
+void Session::textDocument(const char *file, const char *ctype)
+{
+	char buf[256];
+	FILE *fp;
+	char *ep;
+
+	if(strchr(file, '/'))
+		snprintf(buf, sizeof(buf), "%s/%s",
+			server->getLast("prefix"), file);
+	else
+		snprintf(buf, sizeof(buf), "%s/%s", 
+			Service::webservice.getString("datafiles"), file);
+
+	fp = fopen(buf, "r");
+	if(!fp)
+		rpcFault(404, "Not Found");
+
+	sendHeader(ctype);
+
+	for(;;)
+	{
+		fgets(buf, sizeof(buf), fp);
+		if(feof(fp))
+			break;
+
+		ep = strrchr(buf, '\r');
+		if(!ep || (ep[1] && ep[1] != '\n') )
+			ep = strchr(buf, '\n');
+
+		if(ep)
+		{
+			*ep = 0;
+			sendText(buf);
+			sendText("\r\n");
+		}
+		else
+			sendText(buf);
+	}
+	fclose(fp);
 	syncExit();
 }
 	
