@@ -35,6 +35,22 @@ const char *Checks::chkSay(Line *line, ScriptImage *img)
 	return NULL;
 }		
 
+const char *Checks::chkParam(Line *line, ScriptImage *img)
+{
+	unsigned idx = 0;
+
+	if(getMember(line))
+		return "param has no members";
+
+	if(line->argc < 1)
+		return "param requires at least one keyword pair";
+
+	if(getOption(line, &idx))
+		return "param uses only keyword pairs";
+
+	return NULL;
+}
+
 const char *Checks::chkExit(Line *line, ScriptImage *img)
 {
 	if(getMember(line))
