@@ -128,7 +128,7 @@ Keydata keyoptions;
 
 void liveConfig(void)
 {
-	const char *cfgid = Process::getEnv("BAYONNE_CONFIG");
+	const char *cfgid = Process::getEnv("CONFIG");
 
 	char path[256];
 	char lang[32];
@@ -284,11 +284,15 @@ void liveConfig(void)
         }
 
 #ifdef	HAVE_LIBEXEC
-	if(!libdef)
-		runtime.setValue("definitions", "libexec.def");
+	cp = Process::getEnv("LIBEXEC");
+	if(!cp || strnicmp(cp, "no", 2))
+	{
+		if(!libdef)
+			runtime.setValue("definitions", "libexec.def");
 
-	if(!ttsdef)
-		runtime.setValue("definitions", "tts.def");
+		if(!ttsdef)
+			runtime.setValue("definitions", "tts.def");
+	}
 #endif
 
 	cp = keyoptions.getLast("prefix");
@@ -435,6 +439,14 @@ void liveConfig(void)
 #endif
 	Script::exec_token = "bayonne:";
 
+	cp = Process::getEnv("LIBEXEC");
+	if(!cp || !*cp)
+	{
+		cp = keyengine.getLast("libexec");
+		if(cp && *cp)
+			Process::setEnv("LIBEXEC", cp, true);
+	}
+
 	cp = keyengine.getLast("virtual");
 	if(cp)
 		overdraft = atoi(cp);
@@ -444,7 +456,7 @@ void liveConfig(void)
 
 void loadConfig(void)
 {
-	const char *cfgid = Process::getEnv("BAYONNE_CONFIG");
+	const char *cfgid = Process::getEnv("CONFIG");
 	char path[128];
 
     if(cfgid)
@@ -549,6 +561,7 @@ bool parseConfig(char **argv)
 	if(cp && atoi(cp) > 0)
 		keyengine.setValue("timeslots", cp);
 #endif
+
 	++argv;
 
 retry:
