@@ -20,6 +20,33 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+bool Methods::scrParam(void)
+{
+	Line *line = getLine();
+	const char *id, *value;
+	unsigned pos = 0;
+	char buf[80];
+	
+	while(pos < line->argc)
+	{
+		id = line->args[pos++];
+		if(!id)
+			break;
+
+		if(*id != '=')
+			continue;
+		++id;
+		value = getContent(line->args[pos++]);
+		if(!value)
+			continue;
+
+		snprintf(buf, sizeof(buf), "param.%s", id);
+		setConst(buf, value);
+	}
+	advance();
+	return true;
+}
+
 bool Methods::scrExit(void)
 {
 	const char *reason = getValue(NULL);
@@ -388,9 +415,16 @@ bool Methods::scrPosition(void)
 
 bool Methods::scrLibexec(void)
 {
-	const char *cp = getKeyword("results");
+	const char *cp = Process::getEnv("LIBEXEC");
 	Symbol *sym = NULL;
 
+	if(cp && !strnicmp(cp, "no", 2))
+	{
+		error("libexec-unsupported");
+		return true;
+	}
+
+	cp = getKeyword("results");
 	if(cp)
 		sym = mapSymbol(cp);
 
