@@ -63,6 +63,8 @@ ScriptRuntime()
 			(Check)&Checks::chkPaths},
 		{"path", true, (Method)&Methods::scrPath,
 			(Check)&Checks::chkPaths},
+		{"param", true, (Method)&Methods::scrParam,
+			(Check)&Checks::chkParam},
 		{"voicelib", false, (Method)&Methods::scrVoicelib,
 			(Check)&Checks::chkVoicelib},
 		{"timeslot", true, (Method)&Methods::scrTimeslot,
