@@ -82,7 +82,9 @@ static RETSIGTYPE stop(int signo)
                 Bayonne::errlog("notice", "server exiting; normal termination");
 
 #ifdef	HAVE_LIBEXEC
-	BayonneSysexec::cleanup();
+	cp = Process::getEnv("LIBEXEC");
+	if(!cp || strnicmp(cp, "no", 2))
+		BayonneSysexec::cleanup();
 #endif
 
 	Thread::sleep(100);
@@ -181,6 +183,10 @@ static void loading(void)
 	keysmtp.setEnv("userid");
 	keysmtp.setEnv("secret");
 
+	cp = Process::getEnv("LIBEXEC");
+	if(cp && !strnicmp(cp, "no", 2))
+		goto noexec;
+
 	cp = keyengine.getLast("gateways");
 	if(cp)
 		pri = atoi(cp);
@@ -198,6 +204,7 @@ static void loading(void)
 	BayonneSysexec::allocate(keypaths.getLast("libexec"), bs, pri,
 		keypaths.getLast("modexec"));
 
+noexec:
 #endif
         cp = keyserver.getLast("language");
         if(cp && (strlen(cp) == 2 || cp[2] == '_'))  
@@ -347,7 +354,9 @@ start:
 	count = Bayonne::getTimeslotsUsed();
 
 #ifdef	HAVE_LIBEXEC
-	BayonneSysexec::startup();
+	cp = Process::getEnv("LIBEXEC");
+	if(!cp || strnicmp(cp, "no", 2))
+		BayonneSysexec::startup();
 #endif
 // reload
 	cp = keyserver.getLast("binding");
