@@ -252,6 +252,7 @@ public:
 	bool scrReadpath(void);
 	bool scrWritepath(void);
 	bool scrVoicelib(void);
+	bool scrParam(void);
 	bool scrForm(void);
 	bool scrEndform(void);
 	bool scrEndinput(void);
@@ -296,6 +297,7 @@ public:
 	const char *chkReplay(Line *line, ScriptImage *img);
 	const char *chkRecord(Line *line, ScriptImage *img);
 	const char *chkAppend(Line *line, ScriptImage *img);
+	const char *chkParam(Line *line, ScriptImage *img);
 	const char *chkVoicelib(Line *line, ScriptImage *img);
 	const char *chkLibexec(Line *line, ScriptImage *img);
 	const char *chkLang(Line *line, ScriptImage *img);
